#
# spec file for package calc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 2
%define libname libcalc%{soname}
Name:           calc
Version:        2.12.6.7
Release:        lp152.3.8
Summary:        C-style arbitrary precision calculator
License:        LGPL-2.1
Group:          Productivity/Scientific/Math
Url:            http://www.isthe.com/chongo/tech/comp/calc/index.html
Source0:        http://www.isthe.com/chongo/src/calc/%{name}-%{version}.tar.bz2
Source1:        http://www.isthe.com/chongo/src/calc/checksum.sha-256
Source2:        README.openSUSE
Source3:        calc-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  ncurses-devel >= 5.5
BuildRequires:  readline-devel >= 5.1
Requires:       %{libname} = %{version}-%{release}
Requires:       less >= 358
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Calc is arbitrary precision C-like arithmetic system that is a
calculator, an algorithm prototype and mathematical research tool. 
Calc comes with a rich set of builtin mathematical and programmatic
functions.

%package -n %{libname}
Summary:        Arbitrary precision math library
Group:          System/Libraries

%description -n %{libname}
Part of the calc release consists of an arbitrary precision math link
library.  This link library is used by the calc program to perform its
own calculations.  If you wish, you can ignore the calc program entirely
and call the arbitrary precision math routines from your own C programs.

%package devel
Summary:        Development files for libcalc
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}

%description devel
Part of the calc release consists of an arbitrary precision math link
library.  This link library is used by the calc program to perform its
own calculations.  If you wish, you can ignore the calc program entirely
and call the arbitrary precision math routines from your own C programs.

This package contains the files needed for building programs that use
this library.

%prep
( cd ${RPM_SOURCE_DIR}; ls -l;
  grep $(basename %{SOURCE0}) %{SOURCE1} | \
    sed 's/[[:space:]]\+/  /' | sha256sum -c - || exit 23;
)
%setup -q

cp "%{SOURCE2}" .

sed -i '/${CC} ${LIBCUSTCALC_SHLIB} ${CUSTCALC_OBJ}/a\
\tln -s $@ libcustcalc.so
' custom/Makefile

%define _NC_FLAGS %(ncursesw6-config --cflags)
%define _NC_LIBS %(ncursesw6-config --libs)

%define makevars \\\
    BINDIR=%{_bindir} \\\
    LIBDIR=%{_libdir} \\\
    SCRIPTDIR=%{_datadir}/%{name}/cscript \\\
    CALC_SHAREDIR=%{_datadir}/%{name} \\\
    CALC_INCDIR=%{_includedir}/calc \\\
    MANDIR=%{_mandir}/man1 \\\
    HAVE_FPOS="-DHAVE_NO_FPOS" \\\
    USE_READLINE="-DUSE_READLINE" \\\
    READLINE_LIB="-lreadline -lhistory %{_NC_LIBS} -L./custom -lcustcalc" \\\
    LD_SHARE="%{_NC_LIBS}" \\\
    EXTRA_CFLAGS="%{optflags} -g -fno-strict-aliasing %{_NC_FLAGS}"

%build
make -e %{makevars}

%check
make -e %{makevars} chk

%install
make T=%{buildroot} %{makevars} install
ln -s libcalc.so.%{version} %{buildroot}%{_libdir}/libcalc.so.2
ln -s libcustcalc.so.%{version} %{buildroot}%{_libdir}/libcustcalc.so.2
rmdir %{buildroot}%{_includedir}/calc/custom

# dummy-install some docs etc. to create the symlinks
install -d -m 755 %{buildroot}%{_docdir}/%{name}
install -m 644 \
    BUGS CHANGES COPYING COPYING-LGPL HOWTO.INSTALL LIBRARY \
    README.FIRST README.md README.openSUSE \
    custom/CUSTOM_CAL custom/HOW_TO_ADD \
    %{buildroot}%{_docdir}/%{name}/

# create symlinks to the help-dir for the help command, e.g. "help bugs"
ln -sf %{_docdir}/%{name}/COPYING \
    %{buildroot}%{_datadir}/%{name}/help/COPYING
ln -sf %{_docdir}/%{name}/COPYING-LGPL \
    %{buildroot}%{_datadir}/%{name}/help/COPYING-LGPL
ln -sf %{_docdir}/%{name}/BUGS \
    %{buildroot}%{_datadir}/%{name}/help/bug
ln -sf %{_docdir}/%{name}/BUGS \
    %{buildroot}%{_datadir}/%{name}/help/bugs
ln -sf %{_docdir}/%{name}/CHANGES \
    %{buildroot}%{_datadir}/%{name}/help/changes
ln -sf %{_docdir}/%{name}/CHANGES \
    %{buildroot}%{_datadir}/%{name}/help/change
ln -sf %{_docdir}/%{name}/CUSTOM_CAL \
    %{buildroot}%{_datadir}/%{name}/help/custom_cal
ln -sf %{_docdir}/%{name}/HOW_TO_ADD \
    %{buildroot}%{_datadir}/%{name}/help/new_custom

# add symlink to intro to docdir
ln -sf %{_datadir}/%{name}/help/intro \
    %{buildroot}%{_docdir}/%{name}/what-is-calc.txt

%fdupes %{buildroot}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc BUGS CHANGES COPYING COPYING-LGPL HOWTO.INSTALL LIBRARY
%doc README.FIRST README.md README.openSUSE
%doc custom/CUSTOM_CAL custom/HOW_TO_ADD
%{_bindir}/%{name}
%{_datadir}/%{name}
%doc %{_mandir}/man1/%{name}.1.gz
%doc %{_docdir}/%{name}/what-is-calc.txt

%files -n %{libname}
%defattr(-,root,root)
%attr(755, root, root) %{_libdir}/libcalc.so.*
%attr(755, root, root) %{_libdir}/libcustcalc.so.*

%files devel
%defattr(-, root, root)
%doc %attr(644, root, root) BUGS COPYING COPYING-LGPL LIBRARY
%doc sample_many.c sample_rand.c sample.README README.md README.openSUSE
%{_includedir}/%{name}
%{_libdir}/libcalc.so
%{_libdir}/libcustcalc.so

%changelog
* Thu Mar 29 2018 dnh@opensuse.org
- update to 2.12.6.7
  + various fixes and improvements (e.g. inputbuffer length)
* Tue Jan 30 2018 dnh@opensuse.org
- update to 2.12.6.5
- drop upstreamed calc-qmath-sequence-point.patch
* Thu Jan 18 2018 dnh@opensuse.org
- update to 2.12.6.4
  + Fixed a man page warning about ./myfile
  + Improved gen_v1(h,n) in lucas.cal for cases where h is not a multiple of 3.
  + Optimized the search for v(1) when h is a multiple of 3.
* Thu Sep  7 2017 dnh@opensuse.org
- update to 2.12.6.3
  + Improved gen_v1(h,n) in lucas.cal to use an even faster search method
  + Improved checking in lucas.cal
  + Fixed an C code indenting issue in zfunc.c
* Tue Aug  1 2017 Greg.Freemyer@gmail.com
- trivial doc fix
* Sun Jul 23 2017 dnh@opensuse.org
- update to 2.12.6.1
* Mon Jun  6 2016 dnh@opensuse.org
- update to 2.12.5.6
* Tue May 17 2016 dnh@opensuse.org
- update to 2.12.5.4
  +    Recompile to match current RHEL7.2 libc and friends
  +    Upstream made this release in order to update binary files not used in openSUSE
  +    No actual code change, other than the version number was bumped
* Mon Feb 15 2016 eshmarnev@suse.com
- add calc-rpmlintrc package to spec file
* Sat Feb 13 2016 dnh@opensuse.org
- update to 2.12.5.3
- add calc-qmath-sequence-point.patch
- replace calc-2.12.3.3-no-rpath.patch by using LD_SHARE=""
- add test for checksum
- bit of reworking the spec/merging with my old one (which is based
  on the include upstream calc.spec.in)
* Sun Aug  2 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 2.12.5.0
  + See Changes file for full list of changes
* Tue Oct  1 2013 Greg.Freemyer@gmail.com
- update to calc-2.12.4.13
  * major code cleanup and a few new functions
  * See Changes file for full list of changes
- added %%doc section to %%files
- added README.openSUSE
- changed the libname from libcalc2_12_4_3 to libcalc%%soname
- changed -n libcalc-devel to devel
- added Requires: %%{libname} = %%{version} to devel section
* Fri May 24 2013 Greg.Freemyer@gmail.com
- update to calc-2.12.4.8
  * fixes a bug uncovered in calc which caused script failures when calc
    was called within a while loop in BASH if the while loop was fed from
    stdin, due to calc's redirection/inheritance of stdin and no option to
    change this behavior.
* Thu Dec 27 2012 dvaleev@suse.com
- build with -DHAVE_NO_FPOS. Don't use fgetpos() and fsetpos() but
  use fseek() and ftell() instead. The code that generates
  fposval.h is completely broken. It tries to detect the size of
  fpos_t but fails on ppc.
* Tue Sep  4 2012 Greg.Freemyer@gmail.com
- ran thru spec-cleaner
* Wed Aug 29 2012 Greg.Freemyer@gmail.com
- update to calc-2.12.4.3
  - minor bug fixes
* Tue Sep 30 2008 mmarek@suse.cz
- kill rpath in installed binaries
- compile with $RPM_OPT_FLAGS
- hardlink duplicate files in /usr/share/calc/
- don't package /usr/include
* Tue Sep  2 2008 mmarek@suse.cz
- added missing ldconfig calls
* Thu Aug 21 2008 mmarek@suse.cz
- packaged  calc-2.12.3.3
